package com.ibm.etools.iseries.ae.customtags.gen;

/*  (C) Copyright IBM Corporation, 2003                        
 * All rights reserved. Licensed Materials Property of IBM     
 * US Government Users Restricted Rights -                     
 * Use, duplication or disclosure restricted by                
 * GSA ADP Schedule Contract with IBM Corp.                    
 */

import com.ibm.as400ad.code400.dom.constants.IRecordType; 
import com.ibm.etools.iseries.webfacing.convert.external.IWSTagGenerator;
import com.ibm.etools.iseries.webfacing.convert.external.IWSTagInput;
import com.ibm.etools.iseries.webfacing.convert.external.IRawWebSetting;
import com.ibm.etools.iseries.webfacing.convert.external.ITagOutput;
/**
 * @author hockings
 *
 * This is a simple class that will emit a WebFacing User Defined HTML tag for the called field
 */
public class UsrDefTagGen implements IWSTagGenerator
{
    public boolean generate(IWSTagInput input, ITagOutput output)
    {
        boolean rv = false;
        try
        {
            String prefix = "wf";
            String library = "/webface";
            String tagstring = "";
            // tell the record that another taglib directive needs to be added
            output.addHtmlHeader(prefix, library);
            
            // Get the type of the record
            IRecordType rt = input.getRecordType();
            
            // Start generating the tag
            tagstring += "<wf:usrdef field=\"" + input.getFieldName() + "\" record=\"" + input.getRecordName() + "\"";
            if (true == rt.isSubFile())
            {
            	tagstring += " sflrow=\"<%=rrn%>\"";
            }
            tagstring += ">";


            // Now we are in the body of the tag
            // The user-defined HTML is contained in the content of a WebSetting
            // The assumption can be made that this tag is only called in the case of a
            // user-defined web setting.  To be sure you could add a check here
            // and return false if the  WebSetting ID that was used to invoke
            // this tag generator was not for user-defined HTML.

            // Here extract the value of the WebSetting (this contains the user-defined HTML source
            // and run it through replaceFieldValueSymbol() to convert any field references
            // into their correct HTML representation
            tagstring += input.replaceFieldValueSymbol(input.getWebSetting().getWebSettingValue(), false, input.getRecordName());

            // This tag is done so close it off
            tagstring += "</wf:usrdef>";
            
            // Output the result to be included in the containing record format's JSP           
            output.setTag(tagstring);

            // return true to indicate that the field jsp code was emitted OK
            rv = true;
        }
        catch (Throwable t)
        {
            // getting an exception can't be a good thing
            // so log it and return false and the result will be thrown away
            output.logMessage("ERR", 1, "Exception in PgmDefTagGen =" + t);
            rv = false;
        }
        return rv;
    }
}